Index: uhidev.c
===================================================================
--- uhidev.c	(revision 137107)
+++ uhidev.c	(working copy)
@@ -119,7 +119,7 @@
 	usb_endpoint_descriptor_t *ed;
 	struct uhidev_attach_arg uha;
 	struct uhidev *dev;
-	int size, nrepid, repid, repsz;
+	int maxinpktsize, size, nrepid, repid, repsz;
 	int repsizes[256];
 	int i;
 	void *desc;
@@ -139,6 +139,7 @@
 		(void)usbd_set_protocol(iface, 1);
 #endif
 
+	maxinpktsize = 0;
 	sc->sc_iep_addr = sc->sc_oep_addr = -1;
 	for (i = 0; i < id->bNumEndpoints; i++) {
 		ed = usbd_interface2endpoint_descriptor(iface, i);
@@ -157,9 +158,9 @@
 		    UE_GET_DIR(ed->bEndpointAddress)==UE_DIR_IN? "in" : "out",
 		    ed->bmAttributes & UE_XFERTYPE,
 		    UGETW(ed->wMaxPacketSize), ed->bInterval));
-
 		if (UE_GET_DIR(ed->bEndpointAddress) == UE_DIR_IN &&
 		    (ed->bmAttributes & UE_XFERTYPE) == UE_INTERRUPT) {
+			maxinpktsize = UGETW(ed->wMaxPacketSize);
 			sc->sc_iep_addr = ed->bEndpointAddress;
 		} else if (UE_GET_DIR(ed->bEndpointAddress) == UE_DIR_OUT &&
 		    (ed->bmAttributes & UE_XFERTYPE) == UE_INTERRUPT) {
@@ -204,6 +205,13 @@
 			break;
 		}
 	}
+	if (uaa->vendor == USB_VENDOR_MICROSOFT &&
+	    uaa->product == 0x745) {
+		for (i = 0; i < id->bNumEndpoints; i++) {
+			ed = usbd_interface2endpoint_descriptor(iface, i);
+			ed->bInterval = 10;
+		}
+	}
 
 	if (descptr) {
 		desc = malloc(size, M_USBDEV, M_NOWAIT);
@@ -243,19 +251,17 @@
 		printf("%s: no memory\n", sc->sc_dev.dv_xname);
 		return;
 	}
+
+	/* Just request max packet size for the interrupt pipe */
+	sc->sc_isize = maxinpktsize;
 	sc->sc_nrepid = nrepid;
-	sc->sc_isize = 0;
 
 	for (repid = 0; repid < nrepid; repid++) {
 		repsz = hid_report_size(desc, size, hid_input, repid);
 		DPRINTF(("uhidev_match: repid=%d, repsz=%d\n", repid, repsz));
 		repsizes[repid] = repsz;
-		if (repsz > 0) {
-			if (repsz > sc->sc_isize)
-				sc->sc_isize = repsz;
-		}
 	}
-	sc->sc_isize += nrepid != 1;	/* space for report ID */
+
 	DPRINTF(("uhidev_attach: isize=%d\n", sc->sc_isize));
 
 	uha.parent = sc;
@@ -423,7 +429,7 @@
 	if (scd == NULL || !(scd->sc_state & UHIDEV_OPEN))
 		return;
 #ifdef UHIDEV_DEBUG
-	if (scd->sc_in_rep_size != cc)
+	if (scd->sc_in_rep_size > cc)
 		printf("%s: bad input length %d != %d\n",sc->sc_dev.dv_xname,
 		       scd->sc_in_rep_size, cc);
 #endif
Index: hidms.c
===================================================================
--- hidms.c	(revision 137107)
+++ hidms.c	(working copy)
@@ -257,6 +257,15 @@
 	}
 	printf("\n");
 
+	if ((ms->sc_flags & HIDMS_Z) && ms->sc_loc_z.pos == 0) {
+		/* use next of Y */
+		ms->sc_loc_z.pos = ms->sc_loc_y.pos + ms->sc_loc_y.size;
+		/* disable W (XXX needed?) */
+		ms->sc_flags &= ~HIDMS_W;
+		ms->sc_loc_w.pos = 0;
+		ms->sc_loc_w.size = 0;
+	}
+
 #ifdef HIDMS_DEBUG
 	DPRINTF(("hidms_attach: ms=%p\n", ms));
 	DPRINTF(("hidms_attach: X\t%d/%d\n",
